#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-extras
version:              0.0.0.9
visibility:           public
id:                   th-extras-0.0.0.9-CvcjBwJjd3y963SAv1PqF4
key:                  th-extras-0.0.0.9-CvcjBwJjd3y963SAv1PqF4
license:              LicenseRef-PublicDomain
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/erikd/th-extras
synopsis:             A grab bag of functions for use with Template Haskell
description:
    A grab bag of functions for use with Template Haskell.

    This is basically the place I put all my ugly CPP hacks to support
    the ever-changing interface of the template haskell system by
    providing high-level operations and making sure they work on as many
    versions of Template Haskell as I can.

category:             Template Haskell
abi:                  3b19472bb7ecda688f5fdb64ecd82f01
exposed:              True
exposed-modules:      Language.Haskell.TH.Extras
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-extras-0.0.0.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-extras-0.0.0.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-extras-0.0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-extras
hs-libraries:         HSth-extras-0.0.0.9-CvcjBwJjd3y963SAv1PqF4
depends:
    base-4.18.2.1 containers-0.6.7 syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE
    template-haskell-2.20.0.0
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3

haddock-interfaces:   /usr/share/doc/haskell-th-extras/html/th-extras.haddock
haddock-html:         /usr/share/doc/haskell-th-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

